@@ -16,7 +16,7 @@ from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
 
 from ironic_tempest_plugin.common import waiters
-from ironic_tempest_plugin.tests.api.admin import base
+from ironic_tempest_plugin.tests.api import base
 
 CONF = config.CONF
 
