@@ -11,7 +11,6 @@
 #    under the License.
 
 from oslo_utils import uuidutils
-import six
 from tempest import config
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
@@ -19,7 +18,7 @@ from tempest.lib import exceptions as lib_exc
 
 from ironic_tempest_plugin.common import waiters
 from ironic_tempest_plugin.tests.api.admin import api_microversion_fixture
-from ironic_tempest_plugin.tests.api.admin import base
+from ironic_tempest_plugin.tests.api import base
 
 CONF = config.CONF
 
@@ -136,7 +135,7 @@ class TestNodes(base.BaseBaremetalTest):
         body = self.client.get_node_boot_device(self.node['uuid'])
         self.assertIn('boot_device', body)
         self.assertIn('persistent', body)
-        self.assertIsInstance(body['boot_device'], six.string_types)
+        self.assertIsInstance(body['boot_device'], str)
         self.assertIsInstance(body['persistent'], bool)
 
     @decorators.idempotent_id('3622bc6f-3589-4bc2-89f3-50419c66b133')
@@ -912,7 +911,10 @@ class TestNodeProtected(base.BaseBaremetalTest):
         self.deploy_node(self.node['uuid'])
         self.client.update_node(self.node['uuid'], protected=True,
                                 maintenance=True)
-
+        # undo maintenance because we can't teardown something
+        # in maintenance.
+        self.addCleanup(self.client.update_node, self.node['uuid'],
+                        maintenance=False)
         self.assertRaises(lib_exc.Forbidden,
                           self.client.delete_node,
                           self.node['uuid'])
